@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::Types;
-$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002219';
+$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002220';
 use strict;
 use warnings;
 
@@ -13,14 +13,6 @@ coerce 'DBIx::Class::DeploymentHandler::Databases'
  => from 'Str'
  => via { [$_] };
 
-subtype 'StrSchemaVersion'
- => as 'Str'
- => message {
-  defined $_
-    ? "Schema version (currently '$_') must be a string"
-    : 'Schema version must be defined'
- };
-
 no Moose::Util::TypeConstraints;
 1;
 
